==> cxf-testutils-3.3.0-sources.jar: org/apache/headers/coloc/types/ObjectFactory.java <==

package org.apache.headers.coloc.types;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the org.apache.headers.coloc.types package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {

    private final static QName _Header_QNAME = new QName("http://apache.org/headers/coloc/types", "header");
    private final static QName _InHeader_QNAME = new QName("http://apache.org/headers/coloc/types", "inHeader");
    private final static QName _InHeaderResponse_QNAME = new QName("http://apache.org/headers/coloc/types", "inHeaderResponse");
    private final static QName _OutHeader_QNAME = new QName("http://apache.org/headers/coloc/types", "outHeader");
    private final static QName _OutHeaderResponse_QNAME = new QName("http://apache.org/headers/coloc/types", "outHeaderResponse");
    private final static QName _InoutHeader_QNAME = new QName("http://apache.org/headers/coloc/types", "inoutHeader");
    private final static QName _InoutHeaderResponse_QNAME = new QName("http://apache.org/headers/coloc/types", "inoutHeaderResponse");
    private final static QName _PingMe_QNAME = new QName("http://apache.org/headers/coloc/types", "pingMe");
    private final static QName _PingMeResponse_QNAME = new QName("http://apache.org/headers/coloc/types", "pingMeResponse");
    private final static QName _FaultDetail_QNAME = new QName("http://apache.org/headers/coloc/types", "faultDetail");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: org.apache.headers.coloc.types
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link HeaderInfo }
     * 
     */
    public HeaderInfo createHeaderInfo() {
        return new HeaderInfo();
    }

    /**
     * Create an instance of {@link InHeaderT }
     * 
     */
    public InHeaderT createInHeaderT() {
        return new InHeaderT();
    }

    /**
     * Create an instance of {@link InHeaderResponseT }
     * 
     */
    public InHeaderResponseT createInHeaderResponseT() {
        return new InHeaderResponseT();
    }

    /**
     * Create an instance of {@link OutHeaderT }
     * 
     */
    public OutHeaderT createOutHeaderT() {
        return new OutHeaderT();
    }

    /**
     * Create an instance of {@link OutHeaderResponseT }
     * 
     */
    public OutHeaderResponseT createOutHeaderResponseT() {
        return new OutHeaderResponseT();
    }

    /**
     * Create an instance of {@link InoutHeaderT }
     * 
     */
    public InoutHeaderT createInoutHeaderT() {
        return new InoutHeaderT();
    }

    /**
     * Create an instance of {@link InoutHeaderResponseT }
     * 
     */
    public InoutHeaderResponseT createInoutHeaderResponseT() {
        return new InoutHeaderResponseT();
    }

    /**
     * Create an instance of {@link PingMeT }
     * 
     */
    public PingMeT createPingMeT() {
        return new PingMeT();
    }

    /**
     * Create an instance of {@link PingMeResponseT }
     * 
     */
    public PingMeResponseT createPingMeResponseT() {
        return new PingMeResponseT();
    }

    /**
     * Create an instance of {@link FaultDetailT }
     * 
     */
    public FaultDetailT createFaultDetailT() {
        return new FaultDetailT();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link HeaderInfo }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link HeaderInfo }{@code >}
     */
    @XmlElementDecl(namespace = "http://apache.org/headers/coloc/types", name = "header")
    public JAXBElement<HeaderInfo> createHeader(HeaderInfo value) {
        return new JAXBElement<HeaderInfo>(_Header_QNAME, HeaderInfo.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link InHeaderT }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link InHeaderT }{@code >}
     */
    @XmlElementDecl(namespace = "http://apache.org/headers/coloc/types", name = "inHeader")
    public JAXBElement<InHeaderT> createInHeader(InHeaderT value) {
        return new JAXBElement<InHeaderT>(_InHeader_QNAME, InHeaderT.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link InHeaderResponseT }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link InHeaderResponseT }{@code >}
     */
    @XmlElementDecl(namespace = "http://apache.org/headers/coloc/types", name = "inHeaderResponse")
    public JAXBElement<InHeaderResponseT> createInHeaderResponse(InHeaderResponseT value) {
        return new JAXBElement<InHeaderResponseT>(_InHeaderResponse_QNAME, InHeaderResponseT.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link OutHeaderT }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link OutHeaderT }{@code >}
     */
    @XmlElementDecl(namespace = "http://apache.org/headers/coloc/types", name = "outHeader")
    public JAXBElement<OutHeaderT> createOutHeader(OutHeaderT value) {
        return new JAXBElement<OutHeaderT>(_OutHeader_QNAME, OutHeaderT.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link OutHeaderResponseT }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link OutHeaderResponseT }{@code >}
     */
    @XmlElementDecl(namespace = "http://apache.org/headers/coloc/types", name = "outHeaderResponse")
    public JAXBElement<OutHeaderResponseT> createOutHeaderResponse(OutHeaderResponseT value) {
        return new JAXBElement<OutHeaderResponseT>(_OutHeaderResponse_QNAME, OutHeaderResponseT.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link InoutHeaderT }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link InoutHeaderT }{@code >}
     */
    @XmlElementDecl(namespace = "http://apache.org/headers/coloc/types", name = "inoutHeader")
    public JAXBElement<InoutHeaderT> createInoutHeader(InoutHeaderT value) {
        return new JAXBElement<InoutHeaderT>(_InoutHeader_QNAME, InoutHeaderT.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link InoutHeaderResponseT }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link InoutHeaderResponseT }{@code >}
     */
    @XmlElementDecl(namespace = "http://apache.org/headers/coloc/types", name = "inoutHeaderResponse")
    public JAXBElement<InoutHeaderResponseT> createInoutHeaderResponse(InoutHeaderResponseT value) {
        return new JAXBElement<InoutHeaderResponseT>(_InoutHeaderResponse_QNAME, InoutHeaderResponseT.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link PingMeT }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link PingMeT }{@code >}
     */
    @XmlElementDecl(namespace = "http://apache.org/headers/coloc/types", name = "pingMe")
    public JAXBElement<PingMeT> createPingMe(PingMeT value) {
        return new JAXBElement<PingMeT>(_PingMe_QNAME, PingMeT.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link PingMeResponseT }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link PingMeResponseT }{@code >}
     */
    @XmlElementDecl(namespace = "http://apache.org/headers/coloc/types", name = "pingMeResponse")
    public JAXBElement<PingMeResponseT> createPingMeResponse(PingMeResponseT value) {
        return new JAXBElement<PingMeResponseT>(_PingMeResponse_QNAME, PingMeResponseT.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link FaultDetailT }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link FaultDetailT }{@code >}
     */
    @XmlElementDecl(namespace = "http://apache.org/headers/coloc/types", name = "faultDetail")
    public JAXBElement<FaultDetailT> createFaultDetail(FaultDetailT value) {
        return new JAXBElement<FaultDetailT>(_FaultDetail_QNAME, FaultDetailT.class, null, value);
    }

}

==> cxf-testutils-3.3.10-sources.jar: org/apache/headers/coloc/types/ObjectFactory.java <==

package org.apache.headers.coloc.types;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the org.apache.headers.coloc.types package. 
 * &lt;p&gt;An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {

    private final static QName _Header_QNAME = new QName("http://apache.org/headers/coloc/types", "header");
    private final static QName _InHeader_QNAME = new QName("http://apache.org/headers/coloc/types", "inHeader");
    private final static QName _InHeaderResponse_QNAME = new QName("http://apache.org/headers/coloc/types", "inHeaderResponse");
    private final static QName _OutHeader_QNAME = new QName("http://apache.org/headers/coloc/types", "outHeader");
    private final static QName _OutHeaderResponse_QNAME = new QName("http://apache.org/headers/coloc/types", "outHeaderResponse");
    private final static QName _InoutHeader_QNAME = new QName("http://apache.org/headers/coloc/types", "inoutHeader");
    private final static QName _InoutHeaderResponse_QNAME = new QName("http://apache.org/headers/coloc/types", "inoutHeaderResponse");
    private final static QName _PingMe_QNAME = new QName("http://apache.org/headers/coloc/types", "pingMe");
    private final static QName _PingMeResponse_QNAME = new QName("http://apache.org/headers/coloc/types", "pingMeResponse");
    private final static QName _FaultDetail_QNAME = new QName("http://apache.org/headers/coloc/types", "faultDetail");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: org.apache.headers.coloc.types
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link HeaderInfo }
     * 
     */
    public HeaderInfo createHeaderInfo() {
        return new HeaderInfo();
    }

    /**
     * Create an instance of {@link InHeaderT }
     * 
     */
    public InHeaderT createInHeaderT() {
        return new InHeaderT();
    }

    /**
     * Create an instance of {@link InHeaderResponseT }
     * 
     */
    public InHeaderResponseT createInHeaderResponseT() {
        return new InHeaderResponseT();
    }

    /**
     * Create an instance of {@link OutHeaderT }
     * 
     */
    public OutHeaderT createOutHeaderT() {
        return new OutHeaderT();
    }

    /**
     * Create an instance of {@link OutHeaderResponseT }
     * 
     */
    public OutHeaderResponseT createOutHeaderResponseT() {
        return new OutHeaderResponseT();
    }

    /**
     * Create an instance of {@link InoutHeaderT }
     * 
     */
    public InoutHeaderT createInoutHeaderT() {
        return new InoutHeaderT();
    }

    /**
     * Create an instance of {@link InoutHeaderResponseT }
     * 
     */
    public InoutHeaderResponseT createInoutHeaderResponseT() {
        return new InoutHeaderResponseT();
    }

    /**
     * Create an instance of {@link PingMeT }
     * 
     */
    public PingMeT createPingMeT() {
        return new PingMeT();
    }

    /**
     * Create an instance of {@link PingMeResponseT }
     * 
     */
    public PingMeResponseT createPingMeResponseT() {
        return new PingMeResponseT();
    }

    /**
     * Create an instance of {@link FaultDetailT }
     * 
     */
    public FaultDetailT createFaultDetailT() {
        return new FaultDetailT();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link HeaderInfo }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link HeaderInfo }{@code >}
     */
    @XmlElementDecl(namespace = "http://apache.org/headers/coloc/types", name = "header")
    public JAXBElement<HeaderInfo> createHeader(HeaderInfo value) {
        return new JAXBElement<HeaderInfo>(_Header_QNAME, HeaderInfo.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link InHeaderT }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link InHeaderT }{@code >}
     */
    @XmlElementDecl(namespace = "http://apache.org/headers/coloc/types", name = "inHeader")
    public JAXBElement<InHeaderT> createInHeader(InHeaderT value) {
        return new JAXBElement<InHeaderT>(_InHeader_QNAME, InHeaderT.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link InHeaderResponseT }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link InHeaderResponseT }{@code >}
     */
    @XmlElementDecl(namespace = "http://apache.org/headers/coloc/types", name = "inHeaderResponse")
    public JAXBElement<InHeaderResponseT> createInHeaderResponse(InHeaderResponseT value) {
        return new JAXBElement<InHeaderResponseT>(_InHeaderResponse_QNAME, InHeaderResponseT.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link OutHeaderT }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link OutHeaderT }{@code >}
     */
    @XmlElementDecl(namespace = "http://apache.org/headers/coloc/types", name = "outHeader")
    public JAXBElement<OutHeaderT> createOutHeader(OutHeaderT value) {
        return new JAXBElement<OutHeaderT>(_OutHeader_QNAME, OutHeaderT.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link OutHeaderResponseT }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link OutHeaderResponseT }{@code >}
     */
    @XmlElementDecl(namespace = "http://apache.org/headers/coloc/types", name = "outHeaderResponse")
    public JAXBElement<OutHeaderResponseT> createOutHeaderResponse(OutHeaderResponseT value) {
        return new JAXBElement<OutHeaderResponseT>(_OutHeaderResponse_QNAME, OutHeaderResponseT.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link InoutHeaderT }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link InoutHeaderT }{@code >}
     */
    @XmlElementDecl(namespace = "http://apache.org/headers/coloc/types", name = "inoutHeader")
    public JAXBElement<InoutHeaderT> createInoutHeader(InoutHeaderT value) {
        return new JAXBElement<InoutHeaderT>(_InoutHeader_QNAME, InoutHeaderT.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link InoutHeaderResponseT }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link InoutHeaderResponseT }{@code >}
     */
    @XmlElementDecl(namespace = "http://apache.org/headers/coloc/types", name = "inoutHeaderResponse")
    public JAXBElement<InoutHeaderResponseT> createInoutHeaderResponse(InoutHeaderResponseT value) {
        return new JAXBElement<InoutHeaderResponseT>(_InoutHeaderResponse_QNAME, InoutHeaderResponseT.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link PingMeT }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link PingMeT }{@code >}
     */
    @XmlElementDecl(namespace = "http://apache.org/headers/coloc/types", name = "pingMe")
    public JAXBElement<PingMeT> createPingMe(PingMeT value) {
        return new JAXBElement<PingMeT>(_PingMe_QNAME, PingMeT.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link PingMeResponseT }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link PingMeResponseT }{@code >}
     */
    @XmlElementDecl(namespace = "http://apache.org/headers/coloc/types", name = "pingMeResponse")
    public JAXBElement<PingMeResponseT> createPingMeResponse(PingMeResponseT value) {
        return new JAXBElement<PingMeResponseT>(_PingMeResponse_QNAME, PingMeResponseT.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link FaultDetailT }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link FaultDetailT }{@code >}
     */
    @XmlElementDecl(namespace = "http://apache.org/headers/coloc/types", name = "faultDetail")
    public JAXBElement<FaultDetailT> createFaultDetail(FaultDetailT value) {
        return new JAXBElement<FaultDetailT>(_FaultDetail_QNAME, FaultDetailT.class, null, value);
    }

}
